add_logo: Add Marks

Description Usage Arguments

View source: R/tools.R

Description

Include logo, copyright statement and watermarks.

Usage

1
2
3
4
5
6
7
(ggobj, logo.size = 0.1, logo.loc = c(0.5, 0.5))

add_copyright(ggobj, just = c("center", "bottom"),
  text = "copyright: www.yikdata.com", col = "black")

add_watermark(ggobj, text = "www.yikdata.com", angle = 0,
  alpha = 0.4)

Arguments

ggobj

A ggplot object.

logo.size

Controls the size of logo image.

logo.loc

Coordinates of the center point, which controls the position of logo image.

just

A string or numeric vector specifying the justification of the viewport relative to its (x, y) location. If there are two values, the first value specifies horizontal justification and the second value specifies vertical justification. Possible string values are: "left", "right", "centre", "center", "bottom", and "top". For numeric values, 0 means left alignment and 1 means right alignment.

text

Character to add to the figure.

col

Colour for text.

angle

The angle of text.

alpha

Alpha channel for transparency


purplezippo/ggpkt documentation built on May 21, 2019, 10:34 a.m.