Include logo, copyright statement and watermarks.
1 2 3 4 5 6 7 | add_logo(ggobj, logo.size = 0.1, logo.loc = c(0.5, 0.5))
add_copyright(ggobj, just = c("center", "bottom"),
text = "copyright: www.yikdata.com", col = "black")
add_watermark(ggobj, text = "www.yikdata.com", angle = 0,
alpha = 0.4)
|
ggobj |
A ggplot object. |
logo.size |
Controls the size of logo image. |
logo.loc |
Coordinates of the center point, which controls the position of logo image. |
just |
A string or numeric
vector specifying the justification of the viewport
relative to its (x, y) location. If there are two values, the first
value specifies horizontal justification and the second value specifies
vertical justification. Possible string values are: |
text |
Character to add to the figure. |
col |
Colour for text. |
angle |
The angle of text. |
alpha |
Alpha channel for transparency |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.